package testing;

import com.silanis.esl.sdk.*;
import com.silanis.esl.sdk.builder.*;
import com.silanis.esl.sdk.builder.SignerBuilder.ChallengeBuilder;

public class CarLoan {

	public static void main(String[] args) {
		
		EslClient eslClient = new EslClient(info.API_KEY_SANDBOX, info.API_URL_SANDBOX);
		
		DocumentPackage documentPackage = PackageBuilder.newPackageNamed("Car Loan Application")
		        .withSigner(SignerBuilder.newSignerWithEmail("mail30@mailinator.com")
		                .withFirstName("John")
		                .withLastName("Smith")
		                .withCustomId("Signer1")
		                .withSmsSentTo("418-555-5585")
		                .withAttachmentRequirement(AttachmentRequirementBuilder.newAttachmentRequirementWithName("Driver license")
		                    .withDescription("Please upload a copy of your driver license.")
		                    .isRequiredAttachment()
		                    .build()))
		        .withSigner(SignerBuilder.newSignerWithEmail("mail32@mailinator.com")
		                .withFirstName("Patty")
		                .withLastName("Galant")
		                .withCustomId("Signer2")
		                .challengedWithQuestions(ChallengeBuilder.firstQuestion("What's 1+1?")
		                    .answer("2")))
		        .withDocument(DocumentBuilder.newDocumentWithName("Personal Loan Agreement")
		                .fromFile("../4B-CarLoan.pdf")
		                .enableExtraction()
		                .withSignature(SignatureBuilder.signatureFor("mail30@mailinator.com")
		                        .withName("applicant_signature")
		                        .withPositionExtracted()
		                        .withField(FieldBuilder.signatureDate()
		                                .withName("Date")
		                                .withPositionExtracted())
		                        .withField(FieldBuilder.checkBox()
		                                .withName("agree")
		                                .withPositionExtracted())
		                        .withField(FieldBuilder.radioButton("radioGroup")
		                                .withName("radio1")
		                                .withPositionExtracted()
		                                .withValue("X"))
		                        .withField(FieldBuilder.radioButton("radioGroup")
		                                .withName("radio2")
		                                .withPositionExtracted())
		                        .withField(FieldBuilder.radioButton("radioGroup")
		                                .withName("radio3")
		                                .withPositionExtracted()))
		                .withSignature(SignatureBuilder.signatureFor("mail32@mailinator.com")
		                        .withName("coapplicant_signature")
		                        .withPositionExtracted())              
		                .withInjectedField(FieldBuilder.textField()
		                        .withName("amount")
		                        .withValue("50000"))
		                .withInjectedField(FieldBuilder.textField()
		                        .withName("applicant_name")
		                        .withValue("John Smith"))
		                .withInjectedField(FieldBuilder.textField()
		                        .withName("applicant_email")
		                        .withValue("mail30@mailinator.com"))
		                .withInjectedField(FieldBuilder.textField()
		                        .withName("coapplicant_email")
		                        .withValue("mail32@mailinator.com"))
		                .withInjectedField(FieldBuilder.textField()
		                        .withName("coapplicant_name")
		                        .withValue("Patty Galant"))
		                .withInjectedField(FieldBuilder.textField()
		                        .withName("radio5")
		                        .withValue("X"))
		                )
		        .build();
		
		PackageId packageId = eslClient.createAndSendPackage( documentPackage );
		
		System.out.println(packageId);
	}

}
